@@ -8,7 +8,7 @@ use super::*;
 pub trait ContainerExt {
     fn new(name: impl ToString) -> Self;
     #[must_use]
-    fn env(self, env: impl IntoIterator<Item = (impl ToString, impl ToString)>) -> Self;
+    fn env(self, env: impl IntoIterator<Item = impl ToEnvVar>) -> Self;
     #[must_use]
     fn image(self, image: impl ToString) -> Self;
     #[must_use]
@@ -55,10 +55,10 @@ impl ContainerExt for corev1::Container {
         }
     }
 
-    fn env(self, env: impl IntoIterator<Item = (impl ToString, impl ToString)>) -> Self {
+    fn env(self, env: impl IntoIterator<Item = impl ToEnvVar>) -> Self {
         let env = Some(
             env.into_iter()
-                .map(|(name, value)| corev1::EnvVar::value(name, value))
+                .map(|envvar| ToEnvVar::to_envvar(&envvar))
                 .collect(),
         );
         Self { env, ..self }
